Sovereign Grace Churches | Plant With Us
Author: Church Plant Media
Keywords: church plants, Church Planting, church

# Plant With Us

### Is Jesus leading you into Church Planting?

Church planting isn’t for everyone. It takes qualified, gifted, and called church planters to lead disciple-making disciples on mission with the gospel.

Because of this reality, we are committed to helping men discern the call to church planting. This process involves a national and regional assessment, coaching, and training.

After sending a church planter, we are also committed to his ongoing care and support by providing a relationship and resource network through robust interconnectivity with other church planters, pastors, churches, and events.

### Church planting with Sovereign Grace means partnership from start to finish.

“I wouldn’t be planting this church without the investment of Sovereign Grace in my life. I am so grateful that I am not embarking on this work alone, but have brothers who are linking arms with me as we seek to spur one another on to follow God with all we got.”

Jeff Boettcher—2014 Church Planter in South Philadelphia, PA

“To have access to experienced pastors and church planters around the country is invaluable and has already granted stability and guidance for our plant.”

Jon Payne—2013 Church Planter in Round Rock, TX

“I know that when I have questions or if I am in need, there are many guys who are willing to help. I am very well cared for first as a man of God, then as a husband and father, and then as a pastor. The men around me don’t want me just to be qualified to plant a church, but to stay qualified in my character for the long haul.”

Mike Seaver—2011 Church Planter in Charleston, SC

“Sovereign Grace has provided resources, training, and ongoing support for me and my family throughout this process. When I have questions, there is a long list of Sovereign Grace pastors that stand ready to assist me. There is a tangible sense that we are planting a local church that is connected to a larger community of faith.”

Dave Odom—2013 Church Planter in Franklin, TN

“I know that I will stumble, and I know there will be men around me who will be faithful to point it out. And there will be constant reminders of the gospel, which will protect me. That is one of the major blessings of planting with Sovereign Grace.”

Eric Holter—2011 Church Planter in Durham, NC

“Sovereign Grace has become a partnership where helpful discussions can take place, challenging counsel can be given, and mutual prayer can be provided.”

Dan Birkholz—2013 Church Planter in Northeast Philadelphia, PA

We thank God for all of these men who have been equipped to plant churches with Sovereign Grace and long to see the gospel proclaimed to all nations through the planting and strengthening of local churches.

### Would You Like to Explore Church Planting with Us?